==> fbat_1.0.0.tar.gz: fbat/src/FBAT.h <==
/**
 * C functions used for Family Based Association Test.
 * Created by Weiliang Qiu on March 8, 2005
**/

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<string.h>
#include<ctype.h>
#include<stdarg.h>

#ifdef __APPLE_CC__
#include<sys/malloc.h>
#else
#include<malloc.h>
#endif

#include <R.h>


#define maxI(a, b) ((a)>(b)?(a):(b))
#define minI(a, b) ((a)>(b)?(b):(a))

void myPrintMatD(double *config, int nrow, int ncol);
void myPrintMatI(int *config, int nrow, int ncol);
void *gS_alloc(size_t n, size_t sizeof_something);
void *gS_realloc(void *p, size_t new, size_t old, size_t sizeof_something);
void matTranspose(double *A, int *nrow, int *ncol, double *tA);
void matScalar(double *A, double *a, int *nrow, int *ncol);
void matAdd(double *x, int *n, int *p, double *y, double *out);
void matSub(double *x, int *n, int *p, double *y, double *out);
void matProd(double *A, int *nrow, int *pA, double *B, int *pB, double *C);
void matAssign(double *A, int *nrow, int *ncol, double *B);
void sumaAB(double *A, int *nrowA, int *ncolA, double *B, int *ncolB, 
 	double *a, double *C);
void matIni(double *A, double *a, int *nrow, int *ncol);

///////////////////////////////////////////////////////////////
void condProbCPj(int *parents, int *childj, double *prob, int *compatibleFlag);
void condProbM1PHomojk(int *n, int *m, int *childj, int *childk, 
		double *probj, double *probk, double *probjk);
void condProbMPHeterojk(int *n, int *m, int *config, int *nAA, 
		int *nAB, int *childj, int *childk, double *probj, 
		double *probk, double *probjk);
void Tfun(double *Y, double *offset, int *method, double *T);
void Xfun(int *g, int *alleles, int *nAllele, int *method, int *nX, double *X);
void getSiFun(double *X, int *ncolX, double *T, int *nChildren, double *Si, double *sumTi, double *sumTi2);
void getESiFun(double *X, int *ncolX, double *Prob, int *nP, double *sumTi,
		double *ESi);
void getCovSiFun(double *X, int *ncolX, double *Prob, int *nP, double *sumTi,
		double *sumTi2, double *jointProb, double *CovSi);
int *childrenConfig(int *children, int *nChildren, int *nType, int *nAA,
		int *nAB);
int *possibleGeno(int *parents, int *nParents, int *children, int *nChildren,
		int *nPType, int *compatibleFlag);

void familyiM(int *parentsiM, int *nParentsiM, int *childreniM, 
		int *nChildreniM, int *allelesM, int *nAlleleM, 
		int *genoMethod, int *nX, double *Tvec, double *SiM, 
		double *ESiM, double *CovSiM, int *compatibleFlag);
void fbat(int *ped, int *nrow, int *ncol, int *nFamily, int *familySize, 
		int *genoMethod, int *traitMethod, double *traitOffset, 
		int *alleles, int *nAllele, double *S, double *ES, 
		double *CovS, int *numInfoFamily, 
		int *errorFlag, int *quiet);
void checkCompatibility1(int *parents, int *childj, int *flag);
int checkEqualGeno(int *Geno1, int *Geno2);
void fbatM(int *pedM, int *marker, int *nFamily, int *familySize, 
		int *genoMethod, int *nX, int *traitMethod, 
		double *traitOffset, int *alleles, int *nAllele, double *SM, 
		double *ESM, double *CovSM, int *numInfoM, int *quiet);
void checkCompatible(int *ped, int *nrow, int *ncol, int *nFamily, int *familySize, int *alleles, int *nAllele, int *sampleInfoLen, int *compatibleFlag, int *errorFlag, int *whichMarker, int *quiet);
void checkCompatibleM(int *pedM, int *marker, int *nFamily, int *familySize, 
		int *alleles, int *nAllele, int *sampleInfoLen, int *compatibleFlag, int *errorFlag, int *quiet);
void checkdecomposePed(int *marker, int *pedMi, int *familySize, int *childVec, int *numChildren, int *alleles, int *nAllele, int *sampleInfoLen, int *missingFamily, int *compatibleFlag, int *errorFlag, int *quiet);
void checkoneNuclearFamily(int *marker, int *pedMi, int *familySize, int *alleles, int *nAllele, int *sampleInfoLen, int *missingFamily, int *compatibleFlag, int *errorFlag, int *quiet);
void checkfamilyiM(int *parentsiM, int *nParentsiM, int *childreniM, 
		int *nChildreniM, int *allelesM, int *nAlleleM, 
		int *compatibleFlag, int *errorFlag);

int checkInformative(double *Si, double *ESi, double *CovSi, int *nX);
int checkParentsID(int *pedMi, int familySizei, int j);
void oneNuclearFamily(int *marker, int *pedMi, int *familySize, int *alleles, int *nAllele, int *genoMethod, int *traitMethod, double *traitOffset, int *nX, double *SM, double *ESM, double *CovSM, int *missingFamily, int *numInfoM, int *quiet);

void decomposePed(int *marker, int *pedMi, int *familySize, int *childVec, int *numChildren, int *alleles, int *nAllele, int *genoMethod, int *traitMethod, double *traitOffset, int *nX, double *SM, double *ESM, double *CovSM, int *missingFamily, int *numInfoM, int *quiet);


int isWhitespace(char c);
int countWords(FILE *fp, int iFlag);
int countLines(FILE *fp, int nMarker, int nSampleInfoLen);
void getDimOfFile(char **filename, int *nrow, int *sampleInfoLen, int *nMarker, int *errorFlag);


void getAFreq(int *mat, int *nr, int *nMarker, int *alleles, int *nAllele, 
		int *aFreqMat);
void FlagHomo(int *mat, int *nr, int *nMarker, int *nHET, int *nHOM, 
              int *nMiss1, int*nMiss2, int *flagHomo);
void getOij(int *mat, int *nr, int *nc, int *alleles, int *nAllele,
		int *genotypeVec, int *genotypeFreq, int *nGenotype, 
		int *nHET, int *nHOM,
		int *OijMat, double *EijMat, double *piVec, double *chi2);
void getPed(char **filename, int *ped, int *nrow, int *ncol, int *nMarker, 
		char **markerNames, int *errorFlag);
void getGFreq(int *mat, int *nr, int *nMarker, int *gMat, int *nGenotype, 
		int *countMat);
void getAllGenotypes(int *alleles, int *nAllele, int *Mat, 
		     char **genotypeNames);

==> fbat_1.10.0.tar.gz: fbat/src/FBAT.h <==
/**
 * C functions used for Family Based Association Test.
 * Created by Weiliang Qiu on March 8, 2005
**/

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<string.h>
#include<ctype.h>
#include<stdarg.h>

#ifdef __APPLE_CC__
#include<sys/malloc.h>
#else
#include<malloc.h>
#endif

#include <R.h>


#define maxI(a, b) ((a)>(b)?(a):(b))
#define minI(a, b) ((a)>(b)?(b):(a))

void myPrintMatD(double *config, int nrow, int ncol);
void myPrintMatI(int *config, int nrow, int ncol);
void *gS_alloc(size_t n, size_t sizeof_something);
void *gS_realloc(void *p, size_t new, size_t old, size_t sizeof_something);
void matTranspose(double *A, int *nrow, int *ncol, double *tA);
void matScalar(double *A, double *a, int *nrow, int *ncol);
void matAdd(double *x, int *n, int *p, double *y, double *out);
void matSub(double *x, int *n, int *p, double *y, double *out);
void matProd(double *A, int *nrow, int *pA, double *B, int *pB, double *C);
void matAssign(double *A, int *nrow, int *ncol, double *B);
void sumaAB(double *A, int *nrowA, int *ncolA, double *B, int *ncolB, 
 	double *a, double *C);
void matIni(double *A, double *a, int *nrow, int *ncol);

///////////////////////////////////////////////////////////////
void condProbCPj(int *parents, int *childj, double *prob, int *compatibleFlag);
void condProbM1PHomojk(int *n, int *m, int *childj, int *childk, 
		double *probj, double *probk, double *probjk);
void condProbMPHeterojk(int *n, int *m, int *config, int *nAA, 
		int *nAB, int *childj, int *childk, double *probj, 
		double *probk, double *probjk);
void Tfun(double *Y, double *offset, int *method, double *T);
void Xfun(int *g, int *alleles, int *nAllele, int *method, int *nX, double *X);
void getSiFun(double *X, int *ncolX, double *T, int *nChildren, double *Si, double *sumTi, double *sumTi2);
void getESiFun(double *X, int *ncolX, double *Prob, int *nP, double *sumTi,
		double *ESi);
void getCovSiFun(double *X, int *ncolX, double *Prob, int *nP, double *sumTi,
		double *sumTi2, double *jointProb, double *CovSi);
int *childrenConfig(int *children, int *nChildren, int *nType, int *nAA,
		int *nAB);
int *possibleGeno(int *parents, int *nParents, int *children, int *nChildren,
		int *nPType, int *compatibleFlag);

void familyiM(int *parentsiM, int *nParentsiM, int *childreniM, 
		int *nChildreniM, int *allelesM, int *nAlleleM, 
		int *genoMethod, int *nX, double *Tvec, double *SiM, 
		double *ESiM, double *CovSiM, int *compatibleFlag);
void fbat(int *ped, int *nrow, int *ncol, int *nFamily, int *familySize, 
		int *genoMethod, int *traitMethod, double *traitOffset, 
		int *alleles, int *nAllele, double *S, double *ES, 
		double *CovS, int *numInfoFamily, 
		int *errorFlag, int *quiet);
void checkCompatibility1(int *parents, int *childj, int *flag);
int checkEqualGeno(int *Geno1, int *Geno2);
void fbatM(int *pedM, int *marker, int *nFamily, int *familySize, 
		int *genoMethod, int *nX, int *traitMethod, 
		double *traitOffset, int *alleles, int *nAllele, double *SM, 
		double *ESM, double *CovSM, int *numInfoM, int *quiet);
void checkCompatible(int *ped, int *nrow, int *ncol, int *nFamily, 
                     int *familySize, int *alleles, int *nAllele, 
                     int *sampleInfoLen, int *compatibleFlag, 
                     int *errorFlag, int *whichMarker, 
                     int *nMerrMarker, int *nMerrFamily, 
                     int *nErrFamilySample, int *quiet);
void checkCompatibleM(int *pedM, int *marker, int *nFamily, int *familySize, 
		int *alleles, int *nAllele, int *sampleInfoLen, 
                int *compatibleFlag, 
                int *nMerrMarker, int *nMerrFamily,
                int *quiet);
void checkdecomposePed(int *marker, int *pedMi, int *familySize, 
                       int *childVec, int *numChildren, int *alleles, 
                       int *nAllele, int *sampleInfoLen, int *missingFamily, 
                       int *compatibleFlag, 
                       int *flagMerrMarkerMi, int *quiet);
void checkoneNuclearFamily(int *marker, int *pedMi, int *familySize, 
                           int *alleles, int *nAllele, int *sampleInfoLen, 
                           int *missingFamily, int *compatibleFlag, 
                           int *flagMerrMarkerMi, int *quiet);
void checkfamilyiM(int *parentsiM, int *nParentsiM, int *childreniM, 
		int *nChildreniM, int *allelesM, int *nAlleleM, 
		int *compatibleFlag);

int checkInformative(double *Si, double *ESi, double *CovSi, int *nX);
int checkParentsID(int *pedMi, int familySizei, int j);
void oneNuclearFamily(int *marker, int *pedMi, int *familySize, int *alleles, int *nAllele, int *genoMethod, int *traitMethod, double *traitOffset, int *nX, double *SM, double *ESM, double *CovSM, int *missingFamily, int *numInfoM, int *quiet);

void decomposePed(int *marker, int *pedMi, int *familySize, int *childVec, int *numChildren, int *alleles, int *nAllele, int *genoMethod, int *traitMethod, double *traitOffset, int *nX, double *SM, double *ESM, double *CovSM, int *missingFamily, int *numInfoM, int *quiet);


int isWhitespace(char c);
int countWords(FILE *fp, int iFlag);
int countLines(FILE *fp, int nMarker, int nSampleInfoLen);
void getDimOfFile(char **filename, int *nrow, int *sampleInfoLen, int *nMarker, int *errorFlag);


void getAFreq(int *mat, int *nr, int *nMarker, int *alleles, int *nAllele, 
		int *aFreqMat);
void FlagHomo(int *mat, int *nr, int *nMarker, int *nHET, int *nHOM, 
              int *nMiss1, int*nMiss2, int *flagHomo);
void getOij(int *mat, int *nr, int *nc, int *alleles, int *nAllele,
		int *genotypeVec, int *genotypeFreq, int *nGenotype, 
		int *nHET, int *nHOM,
		int *OijMat, double *EijMat, double *piVec, double *chi2);
void getPed(char **filename, int *ped, int *nrow, int *ncol, int *nMarker, 
		char **markerNames, int *errorFlag);
void getGFreq(int *mat, int *nr, int *nMarker, int *gMat, int *nGenotype, 
		int *countMat);
void getAllGenotypes(int *alleles, int *nAllele, int *Mat, 
		     char **genotypeNames);
